@@ -1,6 +1,6 @@
 package App::PerlWatcher::Engine;
 {
-  $App::PerlWatcher::Engine::VERSION = '0.17_1';
+  $App::PerlWatcher::Engine::VERSION = '0.13';
 }
 # ABSTRACT: Creates Watchers and lets them  notify Frontend with their's Statuses
 
@@ -11,7 +11,8 @@ use warnings;
 use AnyEvent;
 use Carp;
 use Class::Load ':all';
-use Smart::Comments -ENV;
+use Data::Dumper;
+use Devel::Comments;
 use File::Spec;
 use Moo;
 use Path::Class qw(file);
@@ -21,8 +22,6 @@ use App::PerlWatcher::Util::Bootstrap qw/get_home_dir/;
 use App::PerlWatcher::Util::Storable qw/freeze thaw/;
 
 
-
-
 has 'frontend'          => ( is => 'rw');
 
 
@@ -48,24 +47,13 @@ sub _build_watchers {
     my $self = shift;
     my $config = $self->config;
     my @r;
-    my $engine_callback = sub {
-        my $status = shift;
-        AnyEvent::postpone {
-            $self->frontend->update($status);
-        };
-    };
     for my $watcher_definition ( @{ $config -> {watchers} } ) {
         my ($class, $watcher_config )
             = @{ $watcher_definition }{ qw/class config/ };
         my $watcher;
         eval {
             load_class($class);
-            $watcher = $class->new(
-                engine_config => $config,
-                callback      => $engine_callback,
-                %$watcher_config
-            );
-            $watcher->callback($engine_callback);
+            $watcher = $class->new( engine_config => $config, %$watcher_config );
             push @r, $watcher;
         };
         carp "Error creating watcher $class : $@" if $@;
@@ -100,7 +88,16 @@ sub BUILD {
 
 sub start {
     my $self = shift;
-    $_->start for ( @{ $self->watchers } );
+    for my $w ( @{ $self->watchers } ) {
+        $w->start(
+            sub {
+                my $status = shift;
+                AnyEvent::postpone {
+                    $self->frontend->update($status);
+                };
+            }
+        );
+    }
     # actually trigger watchers
     $self->backend->start_loop;
 }
@@ -125,7 +122,6 @@ sub sort_statuses {
     ];
 }
 
-
 1;
 
 __END__
@@ -138,7 +134,7 @@ App::PerlWatcher::Engine - Creates Watchers and lets them  notify Frontend with
 
 =head1 VERSION
 
-version 0.17_1
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -176,21 +172,6 @@ version 0.17_1
                 },
             },
         },
-        {
-            class => 'App::PerlWatcher::Watcher::GenericExecutor',
-            config => {
-                command       => "/bin/ls",
-                arguments     => ["-1a", "/tmp/"],
-                frequency     => 60,
-                timeout       => 5,
-                # filtering "." and ".." files
-                filter        => sub { ($_ !~ /^\.{1,2}$/) && (/\S+/) },
-                rules         => [
-            	    warn  => sub { any { /strange_file.txt/ } @_ },
-                ],
-            }
-        },
-
     ],
  };
 
@@ -210,13 +191,6 @@ version 0.17_1
  # info
  # warn
  # ...
- # or you'll get warn if strange_file.txt suddendly appears
- # in /tmp
-
-=head1 DESCRIPTION
-
-The more detailed description of PerlWatcher application can be found here:
-L<https://github.com/basiliscos/perl-watcher>.
 
 =head1 ATTRIBUTES
 
@@ -265,14 +239,6 @@ and shelf)
 Helper method which sorts statuses in accordance with theirs watchers
 order
 
-=head1 CREDITS
-
-=over 2
-
-Alexandr Ciornii
-
-=back
-
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@gmx.com>
