@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::HTTP;
 {
-  $App::PerlWatcher::Watcher::HTTP::VERSION = '0.17_1';
+  $App::PerlWatcher::Watcher::HTTP::VERSION = '0.13';
 }
 # ABSTRACT: The base role for watching external events via HTTP
 
@@ -11,7 +11,7 @@ use warnings;
 use App::PerlWatcher::EventItem;
 use AnyEvent::HTTP;
 use Carp;
-use Smart::Comments -ENV;
+use Devel::Comments;
 use HTTP::Date;
 use List::MoreUtils qw/any/;
 use Moo::Role;
@@ -85,14 +85,16 @@ sub _build_watcher_callback {
     return $watcher;
 }
 
-sub build_watcher_guard {
-    my $self = shift;
-    return AnyEvent->timer(
+sub start {
+    my ($self, $callback) = @_;
+    $self->callback($callback) if $callback;
+
+    $self->{_w} = AnyEvent->timer(
         after    => 0,
         interval => $self->frequency,
         cb       => sub {
-            $self->watcher_callback->()
-              if $self->active;
+            my $watcher_cb = $self->watcher_callback;
+            $watcher_cb->() if defined( $self -> {_w} );
         }
     );
 }
@@ -122,7 +124,7 @@ App::PerlWatcher::Watcher::HTTP - The base role for watching external events via
 
 =head1 VERSION
 
-version 0.17_1
+version 0.13
 
 =head1 ATTRIBUTES
 
