@@ -1,27 +1,24 @@
 package App::PerlWatcher::Watcher::Ping;
 {
-  $App::PerlWatcher::Watcher::Ping::VERSION = '0.17_1';
+  $App::PerlWatcher::Watcher::Ping::VERSION = '0.13';
 }
-# ABSTRACT: Watches for host availablity via pingig it (ICMP) or knoking to it's port (TCP)
+# ABSTRACT: Watches for host availablity via pingig it. Currently only TCP-port ping.
 
 use 5.12.0;
 use strict;
 use warnings;
 
 use AnyEvent::Socket;
-use AnyEvent::Util;
 use App::PerlWatcher::Watcher;
 use Carp;
-use Smart::Comments -ENV;
+use Devel::Comments;
 use Moo;
-use Net::Ping::External qw(ping);
-
 
 
 has 'host'              => ( is => 'ro', required => 1 );
 
 
-has 'port'              => ( is => 'ro', required => 0 );
+has 'port'              => ( is => 'ro', required => 1 );
 
 
 has 'frequency'         => ( is => 'ro', default => sub{ 60; } );
@@ -37,31 +34,9 @@ sub _build_timeout {
 }
 
 sub _build_watcher_callback {
-    my $self = shift;
-    $self -> {_watcher} = $self->port
-        ? $self->_tcp_watcher_callback
-        : $self->_icmp_watcher_callback;
-}
-
-sub _icmp_watcher_callback {
-    my $self = shift;
-    my $host = $self->host;
-    my $timeout = $self->timeout;
-    return sub {
-        fork_call {
-            my $alive = ping(host => $host, timeout => $timeout);
-            $alive;
-        } sub {
-            my $success = shift;
-            $self->interpret_result( $success, $self->callback);
-        };
-    }
-}
-
-sub _tcp_watcher_callback {
     my $self = shift;
     my ($host, $port ) = ( $self->host, $self->port ); 
-    return sub {
+    $self -> {_watcher} = sub {
         tcp_connect $host, $port, sub {
             my $success = @_ != 0;
             # $! contains error
@@ -78,23 +53,22 @@ sub _tcp_watcher_callback {
     };
 }
 
-sub build_watcher_guard {
-    my $self = shift;
-    return AnyEvent->timer(
+sub start {
+    my ($self, $callback) = @_;
+    $self->callback($callback) if $callback;
+    $self->{_w} = AnyEvent->timer(
         after    => 0,
         interval => $self->frequency,
         cb       => sub {
             $self->watcher_callback->()
-              if $self->active;
+              if defined( $self->{_w} );
         }
     );
 }
 
 sub description {
     my $self = shift;
-    my $description = $self->port
-        ? "Knocking at " . $self->host . ":" . $self->port
-        : "Ping " . $self->host;
+    return "Ping " . $self->host . ":" . $self->port;
 }
 
 
@@ -106,27 +80,11 @@ __END__
 
 =head1 NAME
 
-App::PerlWatcher::Watcher::Ping - Watches for host availablity via pingig it (ICMP) or knoking to it's port (TCP)
+App::PerlWatcher::Watcher::Ping - Watches for host availablity via pingig it. Currently only TCP-port ping.
 
 =head1 VERSION
 
-version 0.17_1
-
-=head1 SYNOPSIS
-
- # use the following config for Engine:
-
-        {
-            class => 'App::PerlWatcher::Watcher::Ping',
-            config => {
-                host    =>  'google.com',
-                frequency   =>  10,
-                on => { fail => { 5 => 'alert' } },
-            },
-        },
- # if the port was defined it does TCP-knock to that port.
- # TCP-knock is required for some hosts, that don't answer to
- # ICMP echo requests, e.g. notorious microsoft.com :)
+version 0.13
 
 =head1 ATTRIBUTES
 
@@ -136,8 +94,7 @@ The watched host
 
 =head2 port
 
-The watched port. If the port was specified, then the watcher does
-tcp knock to the port; otherwise it does icmp ping of the host
+The watched port
 
 =head2 frequency
 
