@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::Rss;
 {
-  $App::PerlWatcher::Watcher::Rss::VERSION = '0.17_1';
+  $App::PerlWatcher::Watcher::Rss::VERSION = '0.13';
 }
 # ABSTRACT: Watches RSS feed and returns last news headers as clickable Eventitems.
 
@@ -11,13 +11,12 @@ use warnings;
 use App::PerlWatcher::EventItem;
 use aliased 'App::PerlWatcher::Openable';
 use Carp;
-use Smart::Comments -ENV;
+use Devel::Comments;
 use HTTP::Date;
 use Moo;
 use XML::Simple;
 
 
-
 has 'url'               => ( is => 'ro', required => 1);
 
 
@@ -73,26 +72,7 @@ App::PerlWatcher::Watcher::Rss - Watches RSS feed and returns last news headers
 
 =head1 VERSION
 
-version 0.17_1
-
-=head1 SYNOPSIS
-
- # use the following config for Engine:
-
-        {
-            class => 'App::PerlWatcher::Watcher::Rss',
-            config => {
-                url         =>  'http://www.opennet.ru/opennews/opennews_all.rss',
-                title       =>  'opennet',
-                frequency   => 60,
-                timeout     => 10,
-                items       =>  5,
-                on          => {
-                        ok      => { 1  => 'notice' },
-                        fail    => { 10 => 'info/max'   },
-                },
-            },
-        },
+version 0.13
 
 =head1 ATTRIBUTES
 
